"""Display gold"""

import random

import serge.common
import serge.blocks.actors
import serge.blocks.layout
import serge.blocks.visualblocks
import serge.actor
from theme import G, theme



class GoldDisplay(serge.actor.MountableActor):
    """Display the gold"""

    def addedToWorld(self, world):
        """Added to the world"""
        super(GoldDisplay, self).addedToWorld(world)
        #
        pic = serge.actor.Actor('gold', 'gold')
        pic.setSpriteName('gold-pot')
        pic.setLayerName('ui-gold')
        self.mountActor(pic, G('gold-pic-posn'))
        #
        self.text = text = serge.blocks.actors.FormattedText(
            'gold', 'gold-text',
            format='$%(gold)d',
            colour=G('gold-text-colour'),
            font_name=G('gold-font-name'),
            font_size=G('gold-font-size'),
            justify='right',
            gold=0,
        )
        text.setLayerName('ui-front')
        self.mountActor(text, G('gold-text-posn'))
        #
        self.target_gold = 0

    def addGold(self, amount):
        """Add some gold"""
        self.target_gold += amount

    def setGold(self, amount, target_gold):
        """Set the gold amount"""
        self.text.setValue('gold', amount)
        self.target_gold = target_gold

    def getGold(self):
        """Return the gold amount"""
        return self.text.getValue('gold')

    def updateActor(self, interval, world):
        """Update the actor"""
        super(GoldDisplay, self).updateActor(interval, world)
        #
        current_gold = self.text.getValue('gold')
        if self.target_gold != current_gold:
            if abs(self.target_gold - current_gold) < 10:
                new_value = self.target_gold
            else:
                new_value = int(0.9 * current_gold + 0.1 * self.target_gold)
            self.text.setValue('gold', new_value)
